@@ -216,8 +216,9 @@ public:
 
         QObject::connect(m_serialPort, &QSerialPort::aboutToClose, q, [this]() {
             Q_Q(QModbusRtuSerialMaster);
-            if (q->state() != QModbusDevice::ClosingState)
-                q->close();
+            Q_UNUSED(q); // To avoid unused variable warning in release mode
+            Q_ASSERT(q->state() == QModbusDevice::ClosingState);
+
             m_sendTimer.stop();
             m_responseTimer.stop();
         });
@@ -291,9 +292,7 @@ public:
             m_current.bytesWritten = 0;
             m_current.numberOfRetries--;
             m_serialPort->write(m_current.adu);
-            // Example: 9600 baud, 11 bit per packet -> 872 char/sec
-            // so: 1000 ms / 872 char = 1.147 ms/char * 3.5 character
-            m_sendTimer.start((1000. / (qreal(m_baudRate) / 11.)) * m_current.adu.size());
+            m_sendTimer.start(m_interFrameDelayMilliseconds);
 
             qCDebug(QT_MODBUS) << "(RTU client) Sent Serial PDU:" << m_current.requestPdu;
             qCDebug(QT_MODBUS_LOW).noquote() << "(RTU client) Sent Serial ADU: 0x" + m_current.adu
