@@ -193,7 +193,9 @@ public:
         });
 
         if (element.timer) {
-            q->connect(q, &QModbusClient::timeoutChanged, element.timer.data(), &QTimer::setInterval);
+            using TypeId = void (QTimer::*)(int);
+            q->connect(q, &QModbusClient::timeoutChanged,
+                       element.timer.data(), static_cast<TypeId>(&QTimer::setInterval));
             QObject::connect(element.timer.data(), &QTimer::timeout, [this, writeToSocket, tId]() {
                 if (!m_transactionStore.contains(tId))
                     return;
